==> hussar-skins-1.0.4.jar: static/bsp/permit/js/resourceManage/resourceAdd.js <==
/**
 * @Description: 资源新增脚本文件
 * @Author: sunZengXin
 * @Date: 2018/3/8.
 */
layui.use(['jquery','layer','Hussar','form', 'laydate','HussarAjax'], function(){
	var form=layui.form,
	laydate = layui.laydate,
	$ = layui.jquery,
	$ax=layui.HussarAjax,
	Hussar = layui.Hussar;
	
	form.on('select(typeList)', function(data){
        if (data.value == '1') {
            $('#resType').hide();
            $("#urlShow").css("display","block");
            $("#urlNames").attr("lay-verify","required|url");
        } else if (data.value == '2') {
        	$("#urlShow").css("display","none");
            $("#urlNames").removeAttr("lay-verify");
        	$('#resType').show();
        }
    })

    //自定义校验
		form.verify({
			url : function(value, item){
				var msg="";
				var ajax = new $ax(Hussar.ctxPath + "/resource/sameUrl", function(data) {
					if(data.length!=0){
						msg= 'URL名称已存在！';
					}
			    }, function(data) {
			        Hussar.error("查询URL名称是否存在失败！");
			    });
			    ajax.set("url",value);
			    ajax.start();
			    return msg;
			}
		})
  //监听提交
  form.on('submit(resourceAdd)', function(data){
  var formData = data.field;
  if(formData.isDefault){
	  formData.isDefault = 1;
  }else{
	  formData.isDefault = 0;
  }
  if(formData.isAudit){
	  formData.isAudit = 1;
  }else{
	  formData.isAudit = 0;
  }
  if(formData.isRepeatAuthenticate){
	  formData.isRepeatAuthenticate = 1;
  }else{
	  formData.isRepeatAuthenticate = 0;
  }
  $.ajax({
		type:"POST",
		contentType:"application/x-www-form-urlencoded",
		url:Hussar.ctxPath + "/resource/resourceSave",
		data:formData,
		async:false,
		success:function(data){
			Hussar.success("保存成功!");
			//刷新父页面
			parent.location.reload();
		},
		error:function(){
			Hussar.error("保存失败!");			
		}
	})
    return false;
  });

});

==> hussar-skins-1.2.0.jar: static/bsp/permit/js/resourceManage/resourceAdd.js <==
/**
 * @Description: 资源新增脚本文件
 * @Author: sunZengXin
 * @Date: 2018/3/8.
 */
layui.use(['jquery','layer','Hussar','form', 'laydate','HussarAjax'], function(){
	var form=layui.form,
	laydate = layui.laydate,
	$ = layui.jquery,
	$ax=layui.HussarAjax,
	Hussar = layui.Hussar;
	
	form.on('select(typeList)', function(data){
        if (data.value == '1') {
            $('#resType').hide();
            $("#urlShow").css("display","block");
            $("#urlNames").attr("lay-verify","required|url");
        } else if (data.value == '2') {
        	$("#urlShow").css("display","none");
            $("#urlNames").removeAttr("lay-verify");
        	$('#resType').show();
        }
    })

    //自定义校验
		form.verify({
			url : function(value, item){
				var msg="";
				var ajax = new $ax(Hussar.ctxPath + "/resource/sameUrl", function(data) {
					if(data.length!=0){
						msg= 'URL名称已存在！';
					}
			    }, function(data) {
			        Hussar.error("查询URL名称是否存在失败！");
			    });
			    ajax.set("url",value);
			    ajax.start();
			    return msg;
			},
			permission : function (value, item) {
                if(!/^[a-zA-Z0-9]+\:{1}[a-zA-z0-9\*]+(\:{1}[a-zA-z0-9\*]+){0,1}$/.test(value)){
                    return '格式为 资源:操作 或 资源:操作:实例'
                }
            }
		})
  //监听提交
  form.on('submit(resourceAdd)', function(data){
  var formData = data.field;
  if(formData.isDefault){
	  formData.isDefault = 1;
  }else{
	  formData.isDefault = 0;
  }
  if(formData.isAudit){
	  formData.isAudit = 1;
  }else{
	  formData.isAudit = 0;
  }
  if(formData.isRepeatAuthenticate){
	  formData.isRepeatAuthenticate = 1;
  }else{
	  formData.isRepeatAuthenticate = 0;
  }
  $.ajax({
		type:"POST",
		contentType:"application/x-www-form-urlencoded",
		url:Hussar.ctxPath + "/resource/resourceSave",
		data:formData,
		async:false,
		success:function(data){
			Hussar.success("保存成功!");
			//刷新父页面
			parent.location.reload();
		},
		error:function(){
			Hussar.error("保存失败!");			
		}
	})
    return false;
  });

});
